;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "consult-project-extra" "20250926.603"
  "Consult integration for project.el."
  '((emacs   "28.1")
    (consult "0.17")
    (project "0.8.1"))
  :url "https://github.com/Qkessler/consult-project-extra"
  :commit "8067e2c0ca29432514dabfb47a45cf1132a03789"
  :revdesc "8067e2c0ca29"
  :keywords '("convenience" "project" "management"))
